@@ -15,6 +15,7 @@ import sys
 from typing import IO, Dict, Union
 
 from botocore.response import StreamingBody
+from typing_extensions import NotRequired
 
 if sys.version_info >= (3, 9):
     from typing import TypedDict
@@ -30,31 +31,18 @@ __all__ = (
     "ResponseMetadataTypeDef",
 )
 
-_RequiredInvokeEndpointAsyncInputRequestTypeDef = TypedDict(
-    "_RequiredInvokeEndpointAsyncInputRequestTypeDef",
+InvokeEndpointAsyncInputRequestTypeDef = TypedDict(
+    "InvokeEndpointAsyncInputRequestTypeDef",
     {
         "EndpointName": str,
         "InputLocation": str,
+        "ContentType": NotRequired[str],
+        "Accept": NotRequired[str],
+        "CustomAttributes": NotRequired[str],
+        "InferenceId": NotRequired[str],
+        "RequestTTLSeconds": NotRequired[int],
     },
 )
-_OptionalInvokeEndpointAsyncInputRequestTypeDef = TypedDict(
-    "_OptionalInvokeEndpointAsyncInputRequestTypeDef",
-    {
-        "ContentType": str,
-        "Accept": str,
-        "CustomAttributes": str,
-        "InferenceId": str,
-        "RequestTTLSeconds": int,
-    },
-    total=False,
-)
-
-
-class InvokeEndpointAsyncInputRequestTypeDef(
-    _RequiredInvokeEndpointAsyncInputRequestTypeDef, _OptionalInvokeEndpointAsyncInputRequestTypeDef
-):
-    pass
-
 
 InvokeEndpointAsyncOutputTypeDef = TypedDict(
     "InvokeEndpointAsyncOutputTypeDef",
@@ -65,33 +53,20 @@ InvokeEndpointAsyncOutputTypeDef = TypedDict(
     },
 )
 
-_RequiredInvokeEndpointInputRequestTypeDef = TypedDict(
-    "_RequiredInvokeEndpointInputRequestTypeDef",
+InvokeEndpointInputRequestTypeDef = TypedDict(
+    "InvokeEndpointInputRequestTypeDef",
     {
         "EndpointName": str,
         "Body": Union[bytes, IO[bytes], StreamingBody],
+        "ContentType": NotRequired[str],
+        "Accept": NotRequired[str],
+        "CustomAttributes": NotRequired[str],
+        "TargetModel": NotRequired[str],
+        "TargetVariant": NotRequired[str],
+        "TargetContainerHostname": NotRequired[str],
+        "InferenceId": NotRequired[str],
     },
 )
-_OptionalInvokeEndpointInputRequestTypeDef = TypedDict(
-    "_OptionalInvokeEndpointInputRequestTypeDef",
-    {
-        "ContentType": str,
-        "Accept": str,
-        "CustomAttributes": str,
-        "TargetModel": str,
-        "TargetVariant": str,
-        "TargetContainerHostname": str,
-        "InferenceId": str,
-    },
-    total=False,
-)
-
-
-class InvokeEndpointInputRequestTypeDef(
-    _RequiredInvokeEndpointInputRequestTypeDef, _OptionalInvokeEndpointInputRequestTypeDef
-):
-    pass
-
 
 InvokeEndpointOutputTypeDef = TypedDict(
     "InvokeEndpointOutputTypeDef",
